package VMOMI::HostNumericSensorHealthState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
